@@ -29,7 +29,7 @@ class JKSparkSession(object):
     def get(cls):
         for key, value in cls._options.items():
             cls._spark = cls._spark.config(key,value)
-        cls._spark = cls._spark.getOrCreate()
-        return cls._spark
+        return cls._spark.getOrCreate()
+
 
 
